@@ -78,6 +78,11 @@ class ConfigHeaderMappings():
             taxonomy_id = config.get('taxonomy', {}).get('id')
             if not taxonomy_id:
                 continue
+
+            taxonomy_column_types = config.get('taxonomy', {}).get('columnTypes'. [])
+            for ct in taxonomy_column_types:
+                self._header_mappings.setdefault(taxonomy_id, {})[name] = h
+
             mapping = config.get('model', {}).get('mapping')
             if not mapping:
                 continue
